@@ -7,8 +7,11 @@ module = sys.modules[__name__]
 
 installed_poppy_creatures = {}
 # Feel free to make a pull request to add your own creature here
-existing_creatures = ['poppy-humanoid', 'poppy-torso', 'poppy-ergo-jr', 'poppy-ergo-starter', 'poppy-6dof-right-arm', 'poppy-dragster-mini', 'poppy-ergo', 'roboticia-quattro', 'roboticia-starter', 'doggy']
-
+existing_creatures = ['poppy-humanoid', 'poppy-torso', 'poppy-ergo-jr',
+                      'poppy-ergo-starter', 'poppy-6dof-right-arm',
+                      'poppy-dragster-mini', 'poppy-ergo', 'roboticia-quattro',
+                      'roboticia-first', 'roboticia-uno', 'roboticia-drive',
+                      'doggy']
 
 for creature in existing_creatures:
     package = creature.replace('-', '_')
